@@ -7,6 +7,7 @@ use IO::Interactive;
 use Scalar::Util;
 use Storable;
 use YAML;
+use Try::Tiny;
 
 use Elive::Util::Type;
 
@@ -40,10 +41,10 @@ sub inspect_type {
 sub _freeze {
     my ($val, $type) = @_;
 
-    for ($val) {
+    do {
+	local ($_) = $val;
 
 	if (!defined) {
-
 	    warn "undefined value of type $type\n"
 	}
 	else {
@@ -65,9 +66,10 @@ sub _freeze {
 		$_ = lc if $type =~ m{^enum};
 	    }
 	    elsif ($type =~ m{^(Int|HiResDate)}ix) {
-		
-		$_ = _tidy_decimal($_);
-		
+
+		$_ = _tidy_decimal($_)
+		    unless $_ eq '0' || m{^[1-9][0-9]*$};
+
 	    }
 	    elsif ($type =~ m{^Ref}ix) {
 		$val = undef;
@@ -77,7 +79,9 @@ sub _freeze {
 		    unless defined;
 	    }
 	}
-    }
+
+	$val = $_;
+    };
 
     return $val;
 }
@@ -94,7 +98,9 @@ sub _thaw {
 
     return unless defined $val;
 
-    for ($val) {
+    do {
+	local ($_) = $val;
+
 	if ($type =~ m{^Bool}i) {
 	    #
 	    # Perlise boolean flags..
@@ -116,44 +122,38 @@ sub _thaw {
 	else {
 	    die "unknown type: $type";
 	}
-    }
+
+	$val = $_;
+    };
 
     return $val;
 }
 
-
 #
 # _tidy_decimal(): general cleanup and normalisation of an integer.
 #               used to clean up numbers for data storage or comparison
 
 sub _tidy_decimal {
-    my $i = shift;;
+    my $i = shift;
     #
     # well a number really. don't convert or sprintf etc
     # to avoid overflow. Just normalise it for potential
     # string comparisons
-
     #
     # l-r trim
     #
-    $i =~ s{^ \s* (.*?) \s* $}{$1}x;
-
-    #
-    # non number => undef
-    #
-    return
-	unless $i =~ m{^[+-]?\d+$};
+    $i =~ s{^ [\s\+]* (-?\d+) \s* $}{$1}x
+	or return;
 
     #
     # remove any leading zeros:
-    # +000123 => 123
+    # 000123 => 123
     # -00045 => -45
     # -000 => 0
     #
 
     $i =~ s{^
-            \+?    # leading plus -discarded 
-            (-?)   # leading minus retained (usually)
+            (-?)   # leading minus retained (for now)
             0*     # leading zeros discarded
             (\d+?) # number - retained
             $}
@@ -283,7 +283,7 @@ sub string {
 	    my ($dt) = ($data_type =~ m{(.*)});
 
 	    return $dt->stringify($_)
-		if eval{$dt->can('stringify')};
+		if try {$dt->can('stringify')};
 	}
 
 	my $reftype =  _reftype($_);
